import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:marquee_widget/marquee_widget.dart';
import 'package:apexid/utils/config.dart';
import 'package:apexid/utils/language.dart';
import 'package:apexid/utils/request.dart';
import 'package:apexid/utils/storage_util.dart';
import 'package:apexid/providers/login_notifier.dart';
import 'package:apexid/res/res_img.dart';
import 'package:apexid/router.dart';
import 'package:apexid/ui/fontManager.dart';
import 'package:provider/provider.dart';

import '../fingerprint.dart';

class ApexIdLoginOptionsScreen extends StatefulWidget {
  final DataPass data;

  const ApexIdLoginOptionsScreen({Key key, this.data}) : super(key: key);
  @override
  _ApexIdLoginOptionsScreenState createState() => _ApexIdLoginOptionsScreenState();
}

class _ApexIdLoginOptionsScreenState extends State<ApexIdLoginOptionsScreen> {
  String lang;
  @override
  void initState() {
    lang = StorageUtil.getString("lang", defValue: "en");
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Consumer<LoginNotifier>(
      builder: (context, value, child) {
        Map<String, dynamic> options = value.loginResponse['options'];
        bool emailOption = options.containsKey("email") ? true : false;
        bool passwordOption = options.containsKey("password") ? true : false;
        bool smsOption = options.containsKey("sms") ? true : false;

        return Directionality(
          textDirection: lang == "fa" ? TextDirection.rtl : TextDirection.ltr,
          child: Scaffold(
            backgroundColor: Colors.grey[800],
            body: Stack(
              overflow: Overflow.visible,
              children: [
                Positioned(
                  top: -300,
                  right: -300,
                  child: Image.asset(
                    ImgResources.shape5,
                    width: 500,
                    package: "apexid",
                    height: 500,
                  ),
                ),
                if (MediaQuery.of(context).viewInsets.bottom == 0)
                  Positioned(
                  bottom: -150,
                  left: -250,
                  child: Image.asset(
                    ImgResources.shape4,
                    package: "apexid",
                    width: 500,
                    height: 500,
                  ),
                ),
                Center(
                  child: Container(
                    constraints: BoxConstraints(maxWidth: (kIsWeb) ? 400 : MediaQuery.of(context).size.width),
                    child: Padding(
                      padding: EdgeInsets.all(20),
                      child: ListView(
                        physics: BouncingScrollPhysics(),
                        children: <Widget>[
                          SizedBox(
                            height: 100,
                          ),
                          Row(
                            mainAxisSize: MainAxisSize.min,
                            mainAxisAlignment: MainAxisAlignment.start,
                            children: <Widget>[
                              Hero(
                                tag: "logo",
                                child: Image.asset(
                                  ImgResources.logo,
                                  package: "apexid",
                                  width: 50,
                                  height: 50,
                                ),
                              ),
                              SizedBox(
                                width: 10,
                              ),
                              Text(
                                Languages.getString(
                                    key: "here_to_get_welcome", lang: lang),
                                style: FontManager(lang).getFont(
                                    GoogleFonts.raleway(
                                        fontSize: 23, color: Colors.white),
                                    customTextStyle: TextStyle(
                                        fontFamily: "IRANSans",
                                        package: "apexid",
                                        fontSize: 23,
                                        color: Colors.white)),
                              ),
                            ],
                          ),
                          SizedBox(
                            height: 25,
                          ),
                          Text(
                            Languages.getString(
                                lang: lang, key: "select_one_of_the_options"),
                            style: FontManager(lang).getFont(
                                GoogleFonts.monda(color: Colors.white),
                                customTextStyle: TextStyle(
                                    fontFamily: "IRANSans",package: "apexid",
                                    color: Colors.white)),
                          ),
                          SizedBox(
                            height: 45,
                          ),
                          SizedBox(
                            height: 5,
                          ),
                          if (smsOption) ...[
                            simpleItem(options['sms']['title'], onTap: () async {
                              MakeRequest.post(
                                request: {
                                  'fingerprint': await FingerPrint().get(),
                                  "cc": "98",
                                  "action": RequestActions.choseOption,
                                  "option": options['sms']['option_id'],
                                  "username": value.username
                                },
                                then: (response, result) {
                                  if (result['action'] == "enter_otp") {
                                    Provider.of<LoginNotifier>(context,
                                            listen: false)
                                        .loginResponse = result;
                                    ApexIdRouter.namedNavigateTo(
                                        context, ApexIdRouter.loginOtpRoute,
                                        replacement: true,
                                        arguments: widget.data);
                                  }
                                },
                              );
                            })
                          ],
                          if (emailOption) ...[
                            SizedBox(
                              height: 8,
                            ),
                            simpleItem(options['email']['title'], onTap: () async {
                              MakeRequest.post(
                                request: {
                                  'fingerprint': await FingerPrint().get(),
                                  "cc": "98",
                                  "action": RequestActions.choseOption,
                                  "option": options['email']['option_id'],
                                  "username": value.username
                                },
                                then: (response, result) {
                                  if (result['action'] == "enter_otp") {
                                    Provider.of<LoginNotifier>(context,
                                            listen: false)
                                        .loginResponse = result;
                                    ApexIdRouter.namedNavigateTo(
                                        context, ApexIdRouter.loginOtpRoute,
                                        replacement: true,
                                        arguments: widget.data);
                                  }
                                },
                              );
                            })
                          ],
                          if (passwordOption) ...[
                            SizedBox(
                              height: 8,
                            ),
                            simpleItem(options['password']['title'],
                                onTap: () async {
                              MakeRequest.post(
                                request: {
                                  'fingerprint': await FingerPrint().get(),
                                  "cc": "98",
                                  "action": RequestActions.choseOption,
                                  "option": options['password']['option_id'],
                                  "username": value.username
                                },
                                then: (response, result) {
                                  if (result['action'] == "enter_password") {
                                    Provider.of<LoginNotifier>(context,
                                            listen: false)
                                        .loginResponse = result;
                                    ApexIdRouter.namedNavigateTo(context,
                                        ApexIdRouter.loginPasswordRoute,
                                        replacement: true,
                                        arguments: widget.data);
                                  }
                                },
                              );
                            })
                          ],
                        ],
                      ),
                    ),
                  ),
                ),
                Positioned(
                  top: 30,
                  left: 20,
                  child: Directionality(
                    textDirection: TextDirection.ltr,
                    child: Tooltip(
                      message: Languages.getString(
                          key: "back_to_login", lang: lang),
                      textStyle: FontManager(lang).getFont(
                          GoogleFonts.raleway(color: Colors.white)),
                      child: IconButton(
                        onPressed: () {
                          ApexIdRouter.namedNavigateTo(
                              context, ApexIdRouter.loginRoute,
                              replacement: true,
                              arguments: widget.data);
                        },
                        icon: Icon(
                          Icons.arrow_back,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  Widget simpleItem(title, {onTap}) {
    return GestureDetector(
      onTap: onTap,
      child: Container(
        decoration: BoxDecoration(
            color: Colors.grey[900], borderRadius: BorderRadius.circular(8)),
        padding: EdgeInsets.symmetric(horizontal: 16),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: <Widget>[
            Expanded(
                child: Marquee(
              child: Text(
                title,
                maxLines: 1,
                style: FontManager(lang)
                    .getFont(GoogleFonts.raleway(color: Colors.white)),
                overflow: TextOverflow.ellipsis,
              ),
              backDuration: Duration(seconds: 1),
              pauseDuration: Duration(seconds: 1),
            )),
            IconButton(
                icon: Icon(
              Icons.arrow_forward,
              color: Colors.white,
            ))
          ],
        ),
      ),
    );
  }
}
