import 'package:apex_flutter_plugin/api/api.dart';
import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:marquee_widget/marquee_widget.dart';
import 'package:apexid/utils/config.dart';
import 'package:apexid/utils/language.dart';
import 'package:apexid/utils/request.dart';
import 'package:apexid/utils/storage_util.dart';
import 'package:apexid/providers/login_notifier.dart';
import 'package:apexid/res/res_img.dart';
import 'package:apexid/router.dart';
import 'package:apexid/ui/fontManager.dart';
import 'package:pin_code_fields/pin_code_fields.dart';
import 'package:provider/provider.dart';

import '../apexid.dart';
import '../fingerprint.dart';
import 'login_screen.dart';

class ApexIdLoginPasswordScreen extends StatefulWidget {

  final DataPass data;

  const ApexIdLoginPasswordScreen({Key key, this.data}) : super(key: key);
  @override
  _ApexIdLoginPasswordScreenState createState() => _ApexIdLoginPasswordScreenState();
}

class _ApexIdLoginPasswordScreenState extends State<ApexIdLoginPasswordScreen> {
  String lang;
  bool showProgress = false;
  TextEditingController _passwordController = TextEditingController();
  @override
  void initState() {
    lang = StorageUtil.getString("lang", defValue: "en");
    super.initState();
  }
  @override
  void dispose() {
    _passwordController.dispose();
    super.dispose();
  }
  @override
  Widget build(BuildContext context) {
    return Consumer<LoginNotifier>(
      builder: (context, value, child) {
        Map<String, dynamic> loginResponse = value.loginResponse;

        return Directionality(
          textDirection: lang == "fa" ? TextDirection.rtl : TextDirection.ltr,
          child: Scaffold(
            backgroundColor: Colors.grey[800],
            body: Stack(
              overflow: Overflow.visible,
              children: [
                Positioned(
                  top: -300,
                  right: -300,
                  child: Image.asset(
                    ImgResources.shape5,
                    package: "apexid",
                    width: 500,
                    height: 500,
                  ),
                ),
                if (MediaQuery.of(context).viewInsets.bottom == 0)
                  Positioned(
                  bottom: -150,
                  left: -280,
                  child: Image.asset(
                    ImgResources.shape4,
                    package: "apexid",
                    width: 500,
                    height: 500,
                  ),
                ),
                Center(
                  child: Container(
                    constraints: BoxConstraints(maxWidth: (kIsWeb) ? 400 : MediaQuery.of(context).size.width),
                    child: Padding(
                      padding: EdgeInsets.all(20),
                      child: ListView(
                        physics: BouncingScrollPhysics(),
                        children: <Widget>[
                          SizedBox(
                            height: 100,
                          ),
                          Row(
                            children: <Widget>[
                              Hero(
                                tag:"logo",
                                child: Image.asset(
                                  ImgResources.logo,
                                  package: "apexid",
                                  width: 50,
                                  height: 50,
                                ),
                              ),
                              SizedBox(
                                width: 10,
                              ),
                              Text(
                                Languages.getString(key: "here_to_get_welcome", lang: lang),
                                style: FontManager(lang).getFont(GoogleFonts.raleway(
                                    fontSize: 23, color: Colors.white), customTextStyle: TextStyle(
                                  fontFamily: "IRANSans",
                                  fontSize: 23,package: "apexid",
                                  color: Colors.white
                                )),
                              ),
                            ],
                          ),
                          SizedBox(
                            height: 25,
                          ),
                          Text(
                            loginResponse['message'],
                            style: FontManager(lang).getFont(GoogleFonts.monda(
                                fontSize: 16, color: Colors.white), customTextStyle: TextStyle(
                                fontFamily: "IRANSans",package: "apexid",
                                fontSize: 16,
                                color: Colors.white
                            )),
                          ),
                          SizedBox(
                            height: 45,
                          ),
                          Directionality(
                            textDirection: TextDirection.ltr,
                            child: TextFormField(
                              controller: _passwordController,
                              onChanged: (String value) {
                                setState(() {
                                  _passwordController.text;
                                });
                              },
                              decoration:InputDecoration(
                                  labelText: Languages.getString(
                                      key: "password", lang: lang),
                                  labelStyle: TextStyle(color: Colors.white),
                                  hintStyle: TextStyle(color: Colors.grey[200]),
                                  hintText: loginResponse['hint'] ?? "",
                                  counterText: "",
                                  prefixIcon: Icon(
                                    Icons.lock,
                                    color: Colors.white,
                                  )
                              ),
                              style: FontManager(lang).getFont(
                                  GoogleFonts.raleway(color: Colors.white)),
                            ),
                          ),
                          SizedBox(
                            height: 5,
                          ),
                          SizedBox(
                            height: 20,
                          ),
                          Directionality(
                            textDirection: TextDirection.ltr,
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.end,
                              children: <Widget>[
                                Text(
                                  Languages.getString(key: "lets_go", lang: lang),
                                  style: FontManager(lang).getFont(GoogleFonts.raleway(
                                      fontSize: 24, color: Colors.white), customTextStyle: TextStyle(
                                      fontFamily: "IRANSans",package: "apexid",
                                      fontSize: 24,
                                      color: Colors.white
                                  )),
                                ),
                                SizedBox(width: 5,),

                                showProgress ? CircularProgressIndicator(strokeWidth: 2,) : IconButton(
                                  onPressed: _passwordController.text.length > 5 ? () async {
                                    setState(() {
                                      showProgress = true;
                                    });
                                    MakeRequest.post(
                                      url: Config.apiUrl,
                                      showProgress: false,
                                      whenComplete: () {
                                        setState(() {
                                          showProgress = false;
                                        });
                                      },
                                      request: {
                                        'fingerprint': await FingerPrint().get(),
                                        "cc": "98",
                                        "action": RequestActions.enterPassword,
                                        "username": value.username,
                                        "password": _passwordController.text
                                      },
                                      then: (response, result) {
                                        print(result);
                                        if(result['ok']){
                                          StorageUtil.putString("access_key", result['access_key']);
                                          Api.shared.config.defaultParameters = {
                                            'api_key': ApexId.shared.apiKey,
                                            "lang": lang,
                                            "access_key": result['access_key'],
                                          };
                                          ApexIdRouter.namedNavigateTo(context, ApexIdRouter.mainRoute,arguments: widget.data, replacement: true);
                                        } else {
                                          setState(() {
                                            _passwordController.text = "";
                                          });
                                          if(result['need_to_login']) {
                                            logout(context);
                                          }
                                          BotToast.showText(text: result['error']['message'] + ": " + result['error']['code'].toString());
                                        }
                                      },
                                    );
                                  } : null,
                                  icon: Icon(
                                    Icons.arrow_forward,
                                    size: 30,
                                  ),
                                  color: Colors.amber,
                                )
                              ],
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                ),
                Positioned(
                  top: 30,
                  left: 20,
                  child: Directionality(
                    textDirection: TextDirection.ltr,
                    child: Tooltip(
                      message: Languages.getString(key: "back_to_login", lang: lang),
                      textStyle:  FontManager(lang).getFont(GoogleFonts.raleway(color: Colors.white)),
                      child: IconButton(
                        onPressed: () {
                          ApexIdRouter.namedNavigateTo(context, ApexIdRouter.loginRoute,
                              arguments: widget.data, replacement: true);
                        },
                        icon: Icon(Icons.arrow_back, color: Colors.white,),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }
}
