import 'package:apex_flutter_plugin/api/api.dart';
import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:apexid/utils/config.dart';
import 'package:apexid/utils/language.dart';
import 'package:apexid/utils/request.dart';
import 'package:apexid/utils/storage_util.dart';
import 'package:apexid/providers/login_notifier.dart';
import 'package:apexid/res/res_img.dart';
import 'package:apexid/router.dart';
import 'package:apexid/ui/fontManager.dart';
import 'package:provider/provider.dart';

import '../apexid.dart';
import '../fingerprint.dart';

class ApexIdLoginScreen extends StatefulWidget {
  final DataPass data;

  const ApexIdLoginScreen({Key key, this.data}) : super(key: key);

  @override
  _ApexIdLoginScreenState createState() => _ApexIdLoginScreenState();
}

void logout(context) {
  StorageUtil.putString("access_key", "null");
  ApexIdRouter.namedNavigateTo(context, ApexIdRouter.loginRoute);
}

class _ApexIdLoginScreenState extends State<ApexIdLoginScreen> {
  String lang;
  bool showProgress = false;
  String _phoneNumberValidatorError;
  TextEditingController _phoneNumber = TextEditingController();

  @override
  void initState() {
    lang = StorageUtil.getString("lang", defValue: "en");
    _phoneNumberValidatorError =
        Languages.getString(key: 'phone_number_should_be_11_char', lang: lang);
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    _phoneNumber.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: lang == "fa" ? TextDirection.rtl : TextDirection.ltr,
      child: Scaffold(
        backgroundColor: Colors.grey[800],
        body: Stack(
          overflow: Overflow.visible,
          children: [
            Positioned(
              top: -300,
              right: -300,
              child: Image.asset(
                ImgResources.shape4,
                package: "apexid",
                width: 500,
                height: 500,
              ),
            ),
            if (MediaQuery.of(context).viewInsets.bottom == 0)
              Positioned(
                bottom: -150,
                left: -250,
                child: Image.asset(
                  ImgResources.shape5,
                  package: "apexid",
                  width: 500,
                  height: 500,
                ),
              ),
            Center(
              child: Container(
                constraints: BoxConstraints(maxWidth: (kIsWeb) ? 400 : MediaQuery.of(context).size.width),
                child: Padding(
                  padding: EdgeInsets.all(20),
                  child: ListView(
                    physics: BouncingScrollPhysics(),
                    children: <Widget>[
                      SizedBox(
                        height: 100,
                      ),
                      Row(
                        children: <Widget>[
                          Hero(
                            tag: "logo",
                            child: Image.asset(
                              ImgResources.logo,
                              package: "apexid",
                              width: 50,
                              height: 50,
                            ),
                          ),
                          SizedBox(
                            width: 10,
                          ),
                          Text(
                            Languages.getString(
                                key: 'here_to_get_welcome', lang: lang),
                            style: FontManager(lang).getFont(
                                GoogleFonts.raleway(
                                    fontSize: 23, color: Colors.white),
                                customTextStyle: TextStyle(
                                    fontFamily: "IRANSans",
                                    fontSize: 23,
                                    package: "apexid",
                                    color: Colors.white)),
                          ),
                        ],
                      ),
                      SizedBox(
                        height: 25,
                      ),
                      Text(
                        Languages.getString(
                            key: 'enter_your_pnumber_description', lang: lang),
                        style: FontManager(lang).getFont(
                            GoogleFonts.monda(fontSize: 16, color: Colors.white),
                            customTextStyle: TextStyle(
                                fontFamily: "IRANSans",
                                fontSize: 16,
                                package: "apexid",
                                color: Colors.white)),
                      ),
                      SizedBox(
                        height: 45,
                      ),
                      TextFormField(
                        onChanged: (value) {
                          if (value.length < 11) {
                            setState(() {
                              _phoneNumberValidatorError = Languages.getString(
                                  key: 'phone_number_should_be_11_char',
                                  lang: lang);
                            });
                            return '';
                          } else {
                            if (value.substring(0, 2) != "09") {
                              setState(() {
                                _phoneNumberValidatorError = Languages.getString(
                                    key: 'phone_number_is_wrong', lang: lang);
                              });
                              return "";
                            }
                            setState(() {
                              _phoneNumberValidatorError = '';
                            });
                            return "";
                          }
                        },
                        keyboardType: TextInputType.number,
                        maxLength: 11,
                        controller: _phoneNumber,
                        decoration: InputDecoration(
                            labelText: Languages.getString(
                                key: "phone_number", lang: lang),
                            labelStyle: TextStyle(color: Colors.white),
                            hintStyle: TextStyle(color: Colors.grey[200]),
                            hintText: "09xxxxxxxxx",
                            counterText: "",
                            prefixIcon: Icon(
                              Icons.phone,
                              color: Colors.white,
                            ),
                            suffixIcon: _phoneNumberValidatorError.isEmpty
                                ? Icon(
                                    Icons.check_circle,
                                    color: Colors.white,
                                  )
                                : Icon(
                                    Icons.cancel,
                                    color: Colors.white,
                                  )),
                        style: FontManager(lang)
                            .getFont(GoogleFonts.raleway(color: Colors.white)),
                      ),
                      SizedBox(
                        height: 5,
                      ),
                      Text(
                        _phoneNumberValidatorError,
                        style: FontManager(lang).getFont(
                            GoogleFonts.raleway(color: Colors.white),
                            customTextStyle: TextStyle(
                                fontFamily: "IRANSans",
                                package: "apexid",
                                color: Colors.white)),
                      ),
                      SizedBox(
                        height: 20,
                      ),
                      Directionality(
                        textDirection: TextDirection.ltr,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.end,
                          children: <Widget>[
                            Text(
                              Languages.getString(key: "next", lang: lang),
                              style: FontManager(lang).getFont(
                                  GoogleFonts.raleway(
                                      fontSize: 24, color: Colors.white),
                                  customTextStyle: TextStyle(
                                      fontFamily: "IRANSans",
                                      fontSize: 24,
                                      package: "apexid",
                                      color: Colors.white)),
                            ),
                            SizedBox(
                              width: 5,
                            ),
                            showProgress
                                ? CircularProgressIndicator(
                                    strokeWidth: 1.5,
                                  )
                                : IconButton(
                                    icon: Icon(
                                      Icons.arrow_forward,
                                      size: 30,
                                    ),
                                    onPressed: _phoneNumberValidatorError.isEmpty
                                        ? () async {
                                            setState(() {
                                              showProgress = true;
                                            });
                                            MakeRequest.post(
                                              whenComplete: () {
                                                setState(() {
                                                  showProgress = false;
                                                });
                                              },
                                              showProgress: false,
                                              request: {
                                                'fingerprint': await FingerPrint().get(),
                                                "cc": "98",
                                                "action": RequestActions.getOptions,
                                                "username": _phoneNumber.text
                                              },
                                              then: (response, result) {
                                                if (result['ok']) {
                                                  Provider.of<LoginNotifier>(
                                                          context,
                                                          listen: false)
                                                      .loginResponse = result;
                                                  Provider.of<LoginNotifier>(
                                                          context,
                                                          listen: false)
                                                      .username = _phoneNumber.text;
                                                  if (result['is_new']) {
                                                    ApexIdRouter.namedNavigateTo(
                                                        context,
                                                        ApexIdRouter.loginOtpRoute,
                                                        arguments: widget.data,
                                                        replacement: true);
                                                  } else {
                                                    ApexIdRouter.namedNavigateTo(
                                                        context,
                                                        ApexIdRouter
                                                            .loginOptionsRoute,
                                                        arguments: widget.data,
                                                        replacement: true);
                                                  }
                                                } else {
                                                  BotToast.showText(
                                                      text: result['error']
                                                              ['message'] +
                                                          ": " +
                                                          result['error']['code'].toString());
                                                }
                                              },
                                            );
                                          }
                                        : null,
                                    color: Colors.amber,
                                  )
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
            Positioned(
              top: 30,
              left: 20,
              child: FlatButton(
                onPressed: () {
                  setState(() {
                    lang = (lang == "fa") ? "en" : "fa";
                    StorageUtil.putString("lang", lang);
                    Api.shared.config.defaultParameters = {
                      'api_key': ApexId.shared.apiKey,
                      'lang': lang
                    };
                  });
                },
                child: Text(
                  lang == "fa" ? "en" : "fa",
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
