import 'package:apex_flutter_plugin/api/api.dart';
import 'package:apex_flutter_plugin/api/base_request.dart';
import 'package:apex_flutter_plugin/api/request.dart';
import 'package:apex_flutter_plugin/api/response.dart';
import 'package:apexid/apexid.dart';
import 'package:apexid/widgets/widget_load.dart';
import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:marquee_widget/marquee_widget.dart';
import 'package:apexid/utils/config.dart';
import 'package:apexid/utils/language.dart';
import 'package:apexid/utils/storage_util.dart';
import 'package:apexid/res/res_img.dart';
import 'package:apexid/ui/fontManager.dart';

import '../fingerprint.dart';

class ApexIdSettingScreen extends StatefulWidget {
  @override
  _ApexIdSettingScreenState createState() => _ApexIdSettingScreenState();
}

class _ApexIdSettingScreenState extends State<ApexIdSettingScreen>
    with WidgetLoadMixin {
  String lang;
  bool showProgress = false;
  bool loggedIn = false;
  String userId;
  TextEditingController _mailController = TextEditingController();
  TextEditingController _passwordController = TextEditingController();
  TextEditingController _passwordHintController = TextEditingController();

  @override
  void initState() {
    lang = StorageUtil.getString("lang", defValue: "en");
    super.initState();
  }

  @override
  void onLoad(BuildContext context) {
    checkLogin();
  }

  Future<bool> checkLogin() async {
    bool ok = false;
    Response resp = await Api.shared.makeRequest(IsolateModel(
      Request({
        'fingerprint': await FingerPrint().get(),
        "api_key": ApexId.shared.apiKey,
        "action": RequestActions.checkLogin,
        "access_key": StorageUtil.getString("access_key", defValue: 'null')
      }, method: Method.POST),
      url: Config.apiUrl,
    ));
    if (resp.statusCode == 200) {
      if (resp.result.params['ok']) {
        ok = true;
        setState(() {
          loggedIn = true;
          _mailController.text = resp.result.params['result']['email'];
          _passwordHintController.text =
              resp.result.params['result']['password_hint'];
          userId = resp.result.params['result']['user_id'];
        });
      } else {
        if (resp.result.params['need_to_login']) {
          ApexId.shared.logoutFromApexId(developerKey: ApexId.shared.apiKey);
        }
        ApexId.shared.onBack();
        BotToast.showText(text: resp.result.params['error']['message']);
      }
    } else {
      ApexId.shared.onBack();
    }
    return ok;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.grey[800],
      body: loggedIn
          ? Directionality(
              textDirection:
                  lang == "fa" ? TextDirection.rtl : TextDirection.ltr,
              child: Stack(
                overflow: Overflow.visible,
                children: [
                  Positioned(
                    top: -300,
                    right: -300,
                    child: Image.asset(
                      ImgResources.shape5,
                      width: 500,
                      package: "apexid",
                      height: 500,
                    ),
                  ),
                  if (MediaQuery.of(context).viewInsets.bottom == 0)
                    Positioned(
                      bottom: -150,
                      left: -250,
                      child: Image.asset(
                        ImgResources.shape4,
                        package: "apexid",
                        width: 500,
                        height: 500,
                      ),
                    ),
                  Center(
                    child: Container(
                      constraints: BoxConstraints(maxWidth: (kIsWeb) ? 400 : MediaQuery.of(context).size.width),
                      child: Padding(
                        padding: EdgeInsets.all(20),
                        child: ListView(
                          physics: BouncingScrollPhysics(),
                          children: <Widget>[
                            SizedBox(
                              height: 100,
                            ),
                            Row(
                              mainAxisSize: MainAxisSize.min,
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: <Widget>[
                                Hero(
                                  tag: "logo",
                                  child: Image.asset(
                                    ImgResources.logo,
                                    package: "apexid",
                                    width: 50,
                                    height: 50,
                                  ),
                                ),
                                SizedBox(
                                  width: 10,
                                ),
                                Text(
                                  Languages.getString(key: "settings", lang: lang),
                                  style: FontManager(lang).getFont(
                                      GoogleFonts.raleway(
                                          fontSize: 23, color: Colors.white),
                                      customTextStyle: TextStyle(
                                          fontFamily: "IRANSans",
                                          package: "apexid",
                                          fontSize: 23,
                                          color: Colors.white)),
                                ),
                              ],
                            ),
                            SizedBox(
                              height: 25,
                            ),
                            Text(
                              Languages.getString(
                                  lang: lang, key: "settings_description"),
                              style: FontManager(lang).getFont(
                                  GoogleFonts.monda(color: Colors.white),
                                  customTextStyle: TextStyle(
                                      fontFamily: "IRANSans",
                                      package: "apexid",
                                      color: Colors.white)),
                            ),
                            SizedBox(
                              height: 45,
                            ),
                            Column(
                              children: <Widget>[
                                TextFormField(
                                  keyboardType: TextInputType.emailAddress,
                                  maxLength: 150,
                                  controller: _mailController,
                                  decoration: InputDecoration(
                                    labelText: Languages.getString(
                                        key: "mail", lang: lang),
                                    labelStyle: TextStyle(color: Colors.white),
                                    hintStyle: TextStyle(color: Colors.grey[200]),
                                    hintText: "example@domain.com",
                                    counterText: "",
                                    prefixIcon: Icon(
                                      Icons.mail_outline,
                                      color: Colors.white,
                                    ),
                                  ),
                                  style: FontManager(lang).getFont(
                                      GoogleFonts.raleway(color: Colors.white)),
                                ),
                                TextFormField(
                                  keyboardType: TextInputType.text,
                                  maxLength: 100,
                                  controller: _passwordController,
                                  decoration: InputDecoration(
                                    labelText: Languages.getString(
                                        key: "password", lang: lang),
                                    labelStyle: TextStyle(color: Colors.white),
                                    hintStyle: TextStyle(color: Colors.grey[200]),
                                    hintText: "",
                                    counterText: "",
                                    prefixIcon: Icon(
                                      Icons.lock,
                                      color: Colors.white,
                                    ),
                                  ),
                                  style: FontManager(lang).getFont(
                                      GoogleFonts.raleway(color: Colors.white)),
                                ),
                                TextFormField(
                                  keyboardType: TextInputType.text,
                                  maxLength: 100,
                                  controller: _passwordHintController,
                                  decoration: InputDecoration(
                                    labelText: Languages.getString(
                                        key: "password_hint", lang: lang),
                                    labelStyle: TextStyle(color: Colors.white),
                                    hintStyle: TextStyle(color: Colors.grey[200]),
                                    hintText: "",
                                    counterText: "",
                                    prefixIcon: Icon(
                                      Icons.help_outline,
                                      color: Colors.white,
                                    ),
                                  ),
                                  style: FontManager(lang).getFont(
                                      GoogleFonts.raleway(color: Colors.white)),
                                ),
                              ],
                            ),
                            SizedBox(
                              height: 25,
                            ),
                            Directionality(
                              textDirection: TextDirection.ltr,
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.end,
                                children: <Widget>[
                                  Text(
                                    Languages.getString(
                                        key: "setup_options", lang: lang),
                                    style: FontManager(lang).getFont(
                                        GoogleFonts.raleway(
                                            fontSize: 24, color: Colors.white),
                                        customTextStyle: TextStyle(
                                            fontFamily: "IRANSans",
                                            package: "apexid",
                                            fontSize: 24,
                                            color: Colors.white)),
                                  ),
                                  SizedBox(
                                    width: 5,
                                  ),
                                  showProgress
                                      ? CircularProgressIndicator(
                                          strokeWidth: 2,
                                        )
                                      : IconButton(
                                          onPressed: () async {
                                            setState(() {
                                              showProgress = true;
                                            });
                                            var resp = await Api.shared
                                                .makeRequest(IsolateModel(Request({
                                              'fingerprint': await FingerPrint().get(),
                                              "access_key": StorageUtil.getString("access_key"),
                                              "api_key": ApexId.shared.apiKey,
                                              "lang": lang,
                                              "action":
                                                  RequestActions.setUpLoginOptions,
                                              "mail": _mailController.text,
                                              "password": _passwordController.text,
                                              "password_hint":
                                                  _passwordHintController.text,
                                            }),url: Config.apiUrl))
                                                .whenComplete(() {
                                              setState(() {
                                                showProgress = false;
                                              });
                                            });
                                            var response = resp.result.params;
                                            print(response);
                                            if (response['ok']) {
                                              BotToast.showText(
                                                  text: response['message']);
                                            } else {
                                              BotToast.showText(
                                                  text: response['error']['message'] +
                                                      ": " +
                                                      response['error']['code']);
                                            }
                                          },
                                          icon: Icon(
                                            Icons.arrow_forward,
                                            size: 30,
                                          ),
                                          color: Colors.amber,
                                        )
                                ],
                              ),
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                  Positioned(
                    top: 30,
                    left: 20,
                    child: Directionality(
                      textDirection: TextDirection.ltr,
                      child: IconButton(
                        onPressed: () {
                          ApexId.shared.onBack();
                        },
                        icon: Icon(
                          Icons.arrow_back,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
