import 'dart:async';

import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_neumorphic/flutter_neumorphic.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:apexid/res/res_img.dart';
import 'package:apexid/screens/login_screen.dart';
import 'package:apexid/ui/fontManager.dart';
import 'package:apexid/utils/config.dart';
import 'package:apexid/utils/language.dart';
import 'package:apexid/utils/request.dart';
import 'package:apexid/utils/storage_util.dart';
import 'package:apexid/router.dart';
import 'package:apexid/widgets/widget_load.dart';

import '../fingerprint.dart';

class ApexIdSplashScreen extends StatefulWidget {
  final DataPass data;

  const ApexIdSplashScreen({Key key, this.data}) : super(key: key);
  @override
  _ApexIdSplashScreenState createState() => _ApexIdSplashScreenState();
}

class _ApexIdSplashScreenState extends State<ApexIdSplashScreen> with WidgetLoadMixin {
  String lang;

  @override
  void initState() {
    Future.delayed(Duration(milliseconds: 500), () {
      lang = StorageUtil.getString("lang", defValue: "en");
    });
    super.initState();
  }

  @override
  void onLoad(BuildContext context) {
    Timer(Duration(seconds: 1), splashAction);
  }

  Future<bool> checkLogin() async {
    bool ok = false;
    MakeRequest.post(
      request: {
        'fingerprint': await FingerPrint().get(),
        "action": RequestActions.checkLogin,
        "access_key": StorageUtil.getString("access_key", defValue: 'null')
      },
      showProgress: false,
      then: (response, result) {
        if(result['ok']) {
          ApexIdRouter.namedNavigateTo(context, ApexIdRouter.mainRoute,arguments: widget.data, replacement: true);
        } else {
          if(result['need_to_login']) {
            logout(context);
          }
          BotToast.showText(text: result['error']['message']);
        }
      },
    );
    return ok;
  }

  void splashAction() {
    String accessKey = (StorageUtil.getString("access_key", defValue: 'null'));
    if (accessKey != 'null') {
      checkLogin();
    } else {
      ApexIdRouter.namedNavigateTo(context, ApexIdRouter.loginRoute,arguments: widget.data, replacement: true);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.grey[800],
      body: Stack(
        children: <Widget>[
          Positioned(
            top: -300,
            right: -300,
            child: Image.asset(
              ImgResources.shape4,
              package: "apexid",
              width: 500,
              height: 500,
            ),
          ),
          Positioned(
            bottom: -300,
            left: -250,
            child: Image.asset(
              ImgResources.shape5,
              package: "apexid",
              width: 500,
              height: 500,
            ),
          ),
          Center(
              child: Hero(
                tag:"logo",
                child: Image.asset(
            ImgResources.logo,
                  package: "apexid",
                  width: 220,
            height: 220,
          ),
              )),
        ],
      ),
    );
  }
}
